LinearGradientBlur class

Parameters to use to create a blur texture for the ProgressiveBlurWidget.

By itself it can only create a linear gradient blur. For more complex blur effects, you can create a custom blur texture and provide it to the widget.

Constructors

LinearGradientBlur({required List<double> values, required List<double> stops, required Alignment start, required Alignment end})
const

Properties

end Alignment
The alignment of the end of the gradient.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start Alignment
The alignment of the start of the gradient.
final
stops List<double>
List of stops to be used in the gradient. Must be the same length as values.
final
values List<double>
List of values to be used in the gradient. 1.0 represents maximum blur, 0.0 represents no blur.
final

Methods

createTexture({int width = 128, int height = 128}) Image
Creates the blur texture. By default, width and height are set to 128.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override