blurTextureDimensions property
Dimensions of the blur texture. If not provided, it will be set to 128.
If you notice that the blur appears to be blocky, you can try increasing this value.
Implementation
final int blurTextureDimensions;
Dimensions of the blur texture. If not provided, it will be set to 128.
If you notice that the blur appears to be blocky, you can try increasing this value.
final int blurTextureDimensions;