precache static method
Precaches the blur shader so that it can be used synchronously later.
This should be called as early as possible in your app (e.g. in main()).
Implementation
static Future<void> precache() {
return ShaderBuilder.precacheShader(_shaderAssetKey);
}